@@ -8,6 +8,7 @@ import sys
 import time
 import traceback as tb
 import uuid
+
 from google.cloud import pubsub_v1
 
 import octue.exceptions
@@ -45,7 +46,7 @@ class Service(CoolNameable):
     :return None:
     """
 
-    def __init__(self, backend, service_id=None, run_function=None):
+    def __init__(self, backend, service_id=None, run_function=None, *args, **kwargs):
         if service_id is None:
             self.id = f"{OCTUE_NAMESPACE}.{str(uuid.uuid4())}"
         elif not service_id:
@@ -62,7 +63,7 @@ class Service(CoolNameable):
         self._credentials = GCPCredentialsManager(backend.credentials_environment_variable).get_credentials()
         self.publisher = pubsub_v1.PublisherClient(credentials=self._credentials, batch_settings=BATCH_SETTINGS)
         self._current_question = None
-        super().__init__()
+        super().__init__(*args, **kwargs)
 
     def __repr__(self):
         return f"<{type(self).__name__}({self.name!r})>"
@@ -226,12 +227,13 @@ class Service(CoolNameable):
         )
         response_subscription.create(allow_existing=True)
 
+        serialised_input_manifest = None
         if input_manifest is not None:
-            input_manifest = input_manifest.serialise()
+            serialised_input_manifest = input_manifest.serialise()
 
         self.publisher.publish(
             topic=question_topic.path,
-            data=json.dumps({"input_values": input_values, "input_manifest": input_manifest}).encode(),
+            data=json.dumps({"input_values": input_values, "input_manifest": serialised_input_manifest}).encode(),
             question_uuid=question_uuid,
             forward_logs=str(int(subscribe_to_logs)),
         )
