@@ -5,10 +5,16 @@ from twined.utils import TwinedEncoder
 
 
 class OctueJSONEncoder(TwinedEncoder):
-    """A JSON Encoder which allows objects having a `to_primitive` method to control their own conversion to primitives."""
+    """A JSON encoder which allows objects having a `to_primitive` method to control their own conversion to python
+    primitives.
+    """
 
     def default(self, obj):
+        """Transform the object into a JSON-compatible python primitive.
 
+        :param any obj: any python object
+        :return any: a JSON-compatible python primitive
+        """
         # If the class defines a `to_primitive` method, use it.
         if hasattr(obj, "to_primitive"):
             return obj.to_primitive()
